.. _spkg_notebook_shim:

notebook_shim: A shim layer for notebook traits and config
==========================================================

Description
-----------

A shim layer for notebook traits and config

License
-------

BSD 3-Clause License

Upstream Contact
----------------

https://pypi.org/project/notebook-shim/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_jupyter_server`
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    0.2.3

version_requirements.txt::

    notebook-shim

Equivalent System Packages
--------------------------

(none known)
